@@ -66,16 +66,13 @@ def plot_figs(fig_num, elev, azim):
     Y = np.c_[a, b, c]
 
     # Using SciPy's SVD, this would be:
-    # _, pca_score, V = scipy.linalg.svd(Y, full_matrices=False)
+    # _, pca_score, Vt = scipy.linalg.svd(Y, full_matrices=False)
 
     pca = PCA(n_components=3)
     pca.fit(Y)
-    pca_score = pca.explained_variance_ratio_
-    V = pca.components_
+    V = pca.components_.T
 
-    x_pca_axis, y_pca_axis, z_pca_axis = V.T * pca_score / pca_score.min()
-
-    x_pca_axis, y_pca_axis, z_pca_axis = 3 * V.T
+    x_pca_axis, y_pca_axis, z_pca_axis = 3 * V
     x_pca_plane = np.r_[x_pca_axis[:2], - x_pca_axis[1::-1]]
     y_pca_plane = np.r_[y_pca_axis[:2], - y_pca_axis[1::-1]]
     z_pca_plane = np.r_[z_pca_axis[:2], - z_pca_axis[1::-1]]
