@@ -10,8 +10,8 @@ Using a sub-pipeline, the fitted coefficients can be mapped back into
 the original feature space.
 """
 from sklearn import svm
-from sklearn.datasets import samples_generator
-from sklearn.feature_selection import SelectKBest, f_regression
+from sklearn.datasets import make_classification
+from sklearn.feature_selection import SelectKBest, f_classif
 from sklearn.pipeline import make_pipeline
 from sklearn.model_selection import train_test_split
 from sklearn.metrics import classification_report
@@ -19,7 +19,7 @@ from sklearn.metrics import classification_report
 print(__doc__)
 
 # import some data to play with
-X, y = samples_generator.make_classification(
+X, y = make_classification(
     n_features=20, n_informative=3, n_redundant=0, n_classes=4,
     n_clusters_per_class=2)
 
@@ -27,7 +27,7 @@ X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=42)
 
 # ANOVA SVM-C
 # 1) anova filter, take 3 best ranked features
-anova_filter = SelectKBest(f_regression, k=3)
+anova_filter = SelectKBest(f_classif, k=3)
 # 2) svm
 clf = svm.LinearSVC()
 
