@@ -12,6 +12,7 @@ import numpy as np
 from ..base import BaseEstimator, ClusterMixin
 from ..utils import check_random_state, as_float_array
 from ..utils.validation import _deprecate_positional_args
+from ..utils.deprecation import deprecated
 from ..metrics.pairwise import pairwise_kernels
 from ..neighbors import kneighbors_graph, NearestNeighbors
 from ..manifold import spectral_embedding
@@ -26,16 +27,16 @@ def discretize(vectors, *, copy=True, max_svd_restarts=30, n_iter_max=20,
 
     Parameters
     ----------
-    vectors : array-like, shape: (n_samples, n_clusters)
+    vectors : array-like of shape (n_samples, n_clusters)
         The embedding space of the samples.
 
-    copy : boolean, optional, default: True
+    copy : bool, default=True
         Whether to copy vectors, or perform in-place normalization.
 
-    max_svd_restarts : int, optional, default: 30
+    max_svd_restarts : int, default=30
         Maximum number of attempts to restart SVD if convergence fails
 
-    n_iter_max : int, optional, default: 30
+    n_iter_max : int, default=30
         Maximum number of iterations to attempt in rotation and partition
         matrix search if machine precision convergence is not reached
 
@@ -160,7 +161,8 @@ def discretize(vectors, *, copy=True, max_svd_restarts=30, n_iter_max=20,
 @_deprecate_positional_args
 def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
                         eigen_solver=None, random_state=None, n_init=10,
-                        eigen_tol=0.0, assign_labels='kmeans'):
+                        eigen_tol=0.0, assign_labels='kmeans',
+                        verbose=False):
     """Apply clustering to a projection of the normalized Laplacian.
 
     In practice Spectral Clustering is very useful when the structure of
@@ -176,7 +178,7 @@ def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
 
     Parameters
     ----------
-    affinity : array-like or sparse matrix, shape: (n_samples, n_samples)
+    affinity : {array-like, sparse matrix} of shape (n_samples, n_samples)
         The affinity matrix describing the relationship of the samples to
         embed. **Must be symmetric**.
 
@@ -185,16 +187,17 @@ def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
           - heat kernel of the pairwise distance matrix of the samples,
           - symmetric k-nearest neighbours connectivity matrix of the samples.
 
-    n_clusters : integer, optional
+    n_clusters : int, default=None
         Number of clusters to extract.
 
-    n_components : integer, optional, default is n_clusters
+    n_components : int, default=n_clusters
         Number of eigen vectors to use for the spectral embedding
 
     eigen_solver : {None, 'arpack', 'lobpcg', or 'amg'}
         The eigenvalue decomposition strategy to use. AMG requires pyamg
         to be installed. It can be faster on very large, sparse problems,
-        but may also lead to instabilities
+        but may also lead to instabilities. If None, then ``'arpack'`` is
+        used.
 
     random_state : int, RandomState instance, default=None
         A pseudo random number generator used for the initialization of the
@@ -203,16 +206,16 @@ def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
         deterministic.
         See :term:`Glossary <random_state>`.
 
-    n_init : int, optional, default: 10
+    n_init : int, default=10
         Number of time the k-means algorithm will be run with different
         centroid seeds. The final results will be the best output of
         n_init consecutive runs in terms of inertia.
 
-    eigen_tol : float, optional, default: 0.0
+    eigen_tol : float, default=0.0
         Stopping criterion for eigendecomposition of the Laplacian matrix
         when using arpack eigen_solver.
 
-    assign_labels : {'kmeans', 'discretize'}, default: 'kmeans'
+    assign_labels : {'kmeans', 'discretize'}, default='kmeans'
         The strategy to use to assign labels in the embedding
         space.  There are two ways to assign labels after the laplacian
         embedding.  k-means can be applied and is a popular choice. But it can
@@ -221,6 +224,11 @@ def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
         the 'Multiclass spectral clustering' paper referenced below for
         more details on the discretization approach.
 
+    verbose : bool, default=False
+        Verbosity mode.
+
+        .. versionadded:: 0.24
+
     Returns
     -------
     labels : array of integers, shape: n_samples
@@ -264,10 +272,12 @@ def spectral_clustering(affinity, *, n_clusters=8, n_components=None,
                               eigen_solver=eigen_solver,
                               random_state=random_state,
                               eigen_tol=eigen_tol, drop_first=False)
+    if verbose:
+        print(f'Computing label assignment using {assign_labels}')
 
     if assign_labels == 'kmeans':
         _, labels, _ = k_means(maps, n_clusters, random_state=random_state,
-                               n_init=n_init)
+                               n_init=n_init, verbose=verbose)
     else:
         labels = discretize(maps, random_state=random_state)
 
@@ -301,15 +311,16 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
 
     Parameters
     ----------
-    n_clusters : integer, optional
+    n_clusters : int, default=8
         The dimension of the projection subspace.
 
-    eigen_solver : {None, 'arpack', 'lobpcg', or 'amg'}
+    eigen_solver : {'arpack', 'lobpcg', 'amg'}, default=None
         The eigenvalue decomposition strategy to use. AMG requires pyamg
         to be installed. It can be faster on very large, sparse problems,
-        but may also lead to instabilities.
+        but may also lead to instabilities. If None, then ``'arpack'`` is
+        used.
 
-    n_components : integer, optional, default=n_clusters
+    n_components : int, default=n_clusters
         Number of eigen vectors to use for the spectral embedding
 
     random_state : int, RandomState instance, default=None
@@ -319,7 +330,7 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
         deterministic.
         See :term:`Glossary <random_state>`.
 
-    n_init : int, optional, default: 10
+    n_init : int, default=10
         Number of time the k-means algorithm will be run with different
         centroid seeds. The final results will be the best output of
         n_init consecutive runs in terms of inertia.
@@ -328,7 +339,7 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
         Kernel coefficient for rbf, poly, sigmoid, laplacian and chi2 kernels.
         Ignored for ``affinity='nearest_neighbors'``.
 
-    affinity : string or callable, default 'rbf'
+    affinity : str or callable, default='rbf'
         How to construct the affinity matrix.
          - 'nearest_neighbors' : construct the affinity matrix by computing a
            graph of nearest neighbors.
@@ -345,15 +356,15 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
         increase with similarity) should be used. This property is not checked
         by the clustering algorithm.
 
-    n_neighbors : integer
+    n_neighbors : int, default=10
         Number of neighbors to use when constructing the affinity matrix using
         the nearest neighbors method. Ignored for ``affinity='rbf'``.
 
-    eigen_tol : float, optional, default: 0.0
+    eigen_tol : float, default=0.0
         Stopping criterion for eigendecomposition of the Laplacian matrix
         when ``eigen_solver='arpack'``.
 
-    assign_labels : {'kmeans', 'discretize'}, default: 'kmeans'
+    assign_labels : {'kmeans', 'discretize'}, default='kmeans'
         The strategy to use to assign labels in the embedding
         space. There are two ways to assign labels after the laplacian
         embedding. k-means can be applied and is a popular choice. But it can
@@ -367,23 +378,30 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
         Zero coefficient for polynomial and sigmoid kernels.
         Ignored by other kernels.
 
-    kernel_params : dictionary of string to any, optional
+    kernel_params : dict of str to any, default=None
         Parameters (keyword arguments) and values for kernel passed as
         callable object. Ignored by other kernels.
 
-    n_jobs : int or None, optional (default=None)
-        The number of parallel jobs to run.
+    n_jobs : int, default=None
+        The number of parallel jobs to run when `affinity='nearest_neighbors'`
+        or `affinity='precomputed_nearest_neighbors'`. The neighbors search
+        will be done in parallel.
         ``None`` means 1 unless in a :obj:`joblib.parallel_backend` context.
         ``-1`` means using all processors. See :term:`Glossary <n_jobs>`
         for more details.
 
+    verbose : bool, default=False
+        Verbosity mode.
+
+        .. versionadded:: 0.24
+
     Attributes
     ----------
-    affinity_matrix_ : array-like, shape (n_samples, n_samples)
+    affinity_matrix_ : array-like of shape (n_samples, n_samples)
         Affinity matrix used for clustering. Available only if after calling
         ``fit``.
 
-    labels_ : array, shape (n_samples,)
+    labels_ : ndarray of shape (n_samples,)
         Labels of each point
 
     Examples
@@ -439,7 +457,8 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
     def __init__(self, n_clusters=8, *, eigen_solver=None, n_components=None,
                  random_state=None, n_init=10, gamma=1., affinity='rbf',
                  n_neighbors=10, eigen_tol=0.0, assign_labels='kmeans',
-                 degree=3, coef0=1, kernel_params=None, n_jobs=None):
+                 degree=3, coef0=1, kernel_params=None, n_jobs=None,
+                 verbose=False):
         self.n_clusters = n_clusters
         self.eigen_solver = eigen_solver
         self.n_components = n_components
@@ -454,14 +473,15 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
         self.coef0 = coef0
         self.kernel_params = kernel_params
         self.n_jobs = n_jobs
+        self.verbose = verbose
 
     def fit(self, X, y=None):
         """Perform spectral clustering from features, or affinity matrix.
 
         Parameters
         ----------
-        X : array-like or sparse matrix, shape (n_samples, n_features), or \
-            array-like, shape (n_samples, n_samples)
+        X : {array-like, sparse matrix} of shape (n_samples, n_features), or \
+                array-like of shape (n_samples, n_samples)
             Training instances to cluster, or similarities / affinities between
             instances if ``affinity='precomputed'``. If a sparse matrix is
             provided in a format other than ``csr_matrix``, ``csc_matrix``,
@@ -519,7 +539,8 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
                                            random_state=random_state,
                                            n_init=self.n_init,
                                            eigen_tol=self.eigen_tol,
-                                           assign_labels=self.assign_labels)
+                                           assign_labels=self.assign_labels,
+                                           verbose=self.verbose)
         return self
 
     def fit_predict(self, X, y=None):
@@ -528,8 +549,8 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
 
         Parameters
         ----------
-        X : array-like or sparse matrix, shape (n_samples, n_features), or \
-            array-like, shape (n_samples, n_samples)
+        X : {array-like, sparse matrix} of shape (n_samples, n_features), or \
+                array-like of shape (n_samples, n_samples)
             Training instances to cluster, or similarities / affinities between
             instances if ``affinity='precomputed'``. If a sparse matrix is
             provided in a format other than ``csr_matrix``, ``csc_matrix``,
@@ -541,11 +562,19 @@ class SpectralClustering(ClusterMixin, BaseEstimator):
 
         Returns
         -------
-        labels : ndarray, shape (n_samples,)
+        labels : ndarray of shape (n_samples,)
             Cluster labels.
         """
         return super().fit_predict(X, y)
 
+    def _more_tags(self):
+        return {'pairwise': self.affinity in ["precomputed",
+                                              "precomputed_nearest_neighbors"]}
+
+    # TODO: Remove in 1.1
+    # mypy error: Decorated property not supported
+    @deprecated("Attribute _pairwise was deprecated in "  # type: ignore
+                "version 0.24 and will be removed in 1.1 (renaming of 0.26).")
     @property
     def _pairwise(self):
         return self.affinity in ["precomputed",
