@@ -1,24 +1,26 @@
 # Authors: Shane Grigsby <refuge@rocktalus.com>
 #          Adrin Jalali <adrin.jalali@gmail.com>
 # License: BSD 3 clause
+import platform
+import sys
 
 import numpy as np
 import pytest
 
-from sklearn.datasets.samples_generator import make_blobs
-from sklearn.cluster.optics_ import (OPTICS,
-                                     _extend_region,
-                                     _extract_xi_labels)
+from sklearn.datasets import make_blobs
+from sklearn.cluster import OPTICS
+from sklearn.cluster._optics import _extend_region, _extract_xi_labels
 from sklearn.metrics.cluster import contingency_matrix
 from sklearn.metrics.pairwise import pairwise_distances
-from sklearn.cluster.dbscan_ import DBSCAN
+from sklearn.cluster import DBSCAN
 from sklearn.utils import shuffle
-from sklearn.utils.testing import assert_equal
-from sklearn.utils.testing import assert_array_equal
-from sklearn.utils.testing import assert_raise_message
-from sklearn.utils.testing import assert_allclose
+from sklearn.utils._testing import assert_array_equal
+from sklearn.utils._testing import assert_raise_message
+from sklearn.utils._testing import assert_allclose
+from sklearn.utils.fixes import sp_version, parse_version
 
 from sklearn.cluster.tests.common import generate_clustered_data
+from sklearn.utils import _IS_32BIT
 
 
 rng = np.random.RandomState(0)
@@ -113,8 +115,6 @@ def test_extract_xi():
                             -1, -1, [4] * 5]
     X, expected_labels = shuffle(X, expected_labels, random_state=rng)
 
-    pytest.skip('FIXME (#13739): This is not stable across platforms.')
-
     clust = OPTICS(min_samples=3, min_cluster_size=3,
                    max_eps=20, cluster_method='xi',
                    xi=0.3).fit(X)
@@ -159,7 +159,7 @@ def test_correct_number_of_clusters():
     clust.fit(X)
     # number of clusters, ignoring noise if present
     n_clusters_1 = len(set(clust.labels_)) - int(-1 in clust.labels_)
-    assert_equal(n_clusters_1, n_clusters)
+    assert n_clusters_1 == n_clusters
 
     # check attribute types and sizes
     assert clust.labels_.shape == (len(X),)
@@ -224,7 +224,7 @@ def test_close_extract():
     clust = OPTICS(max_eps=1.0, cluster_method='dbscan',
                    eps=0.3, min_samples=10).fit(X)
     # Cluster ordering starts at 0; max cluster label = 2 is 3 clusters
-    assert_equal(max(clust.labels_), 2)
+    assert max(clust.labels_) == 2
 
 
 @pytest.mark.parametrize('eps', [0.1, .3, .5])
@@ -318,6 +318,11 @@ def test_processing_order():
     assert_array_equal(clust.ordering_, [0, 1, 2, 3])
 
 
+@pytest.mark.skipif(sp_version >= parse_version("1.6.0")
+                    and (platform.machine() == "aarch64" or
+                         (sys.platform == "linux" and _IS_32BIT)),
+                    reason=("Test fails for SciPy 1.6.0 on ARM and on 32-bit "
+                            "linux. See #19111"))
 def test_compare_to_ELKI():
     # Expected values, computed with (future) ELKI 0.7.5 using:
     # java -jar elki.jar cli -dbc.in csv -dbc.filter FixedDBIDsFilter
