@@ -22,12 +22,15 @@ from ._rfe import RFECV
 
 from ._from_model import SelectFromModel
 
+from ._sequential import SequentialFeatureSelector
+
 from ._mutual_info import mutual_info_regression, mutual_info_classif
 
 from ._base import SelectorMixin
 
 
 __all__ = ['GenericUnivariateSelect',
+           'SequentialFeatureSelector',
            'RFE',
            'RFECV',
            'SelectFdr',
