@@ -4,10 +4,11 @@
 
 import numbers
 import warnings
+from collections import Counter
 
 import numpy as np
 import numpy.ma as ma
-from scipy import sparse
+from scipy import sparse as sp
 from scipy import stats
 
 from ..base import BaseEstimator, TransformerMixin
@@ -34,15 +35,20 @@ def _most_frequent(array, extra_value, n_repeat):
        of the array."""
     # Compute the most frequent value in array only
     if array.size > 0:
-        with warnings.catch_warnings():
-            # stats.mode raises a warning when input array contains objects due
-            # to incapacity to detect NaNs. Irrelevant here since input array
-            # has already been NaN-masked.
-            warnings.simplefilter("ignore", RuntimeWarning)
+        if array.dtype == object:
+            # scipy.stats.mode is slow with object dtype array.
+            # Python Counter is more efficient
+            counter = Counter(array)
+            most_frequent_count = counter.most_common(1)[0][1]
+            # tie breaking similarly to scipy.stats.mode
+            most_frequent_value = min(
+                value for value, count in counter.items()
+                if count == most_frequent_count
+            )
+        else:
             mode = stats.mode(array)
-
-        most_frequent_value = mode[0][0]
-        most_frequent_count = mode[1][0]
+            most_frequent_value = mode[0][0]
+            most_frequent_count = mode[1][0]
     else:
         most_frequent_value = 0
         most_frequent_count = 0
@@ -55,11 +61,8 @@ def _most_frequent(array, extra_value, n_repeat):
     elif most_frequent_count > n_repeat:
         return most_frequent_value
     elif most_frequent_count == n_repeat:
-        # Ties the breaks. Copy the behaviour of scipy.stats.mode
-        if most_frequent_value < extra_value:
-            return most_frequent_value
-        else:
-            return extra_value
+        # tie breaking similarly to scipy.stats.mode
+        return min(most_frequent_value, extra_value)
 
 
 class _BaseImputer(TransformerMixin, BaseEstimator):
@@ -76,9 +79,8 @@ class _BaseImputer(TransformerMixin, BaseEstimator):
         """Fit a MissingIndicator."""
         if self.add_indicator:
             self.indicator_ = MissingIndicator(
-                missing_values=self.missing_values, error_on_new=False
-            )
-            self.indicator_.fit(X)
+                missing_values=self.missing_values, error_on_new=False)
+            self.indicator_._fit(X, precomputed=True)
         else:
             self.indicator_ = None
 
@@ -101,7 +103,7 @@ class _BaseImputer(TransformerMixin, BaseEstimator):
         if not self.add_indicator:
             return X_imputed
 
-        hstack = sparse.hstack if sparse.issparse(X_imputed) else np.hstack
+        hstack = sp.hstack if sp.issparse(X_imputed) else np.hstack
         if X_indicator is None:
             raise ValueError(
                 "Data from the missing indicator are not provided. Call "
@@ -126,7 +128,7 @@ class SimpleImputer(_BaseImputer):
 
     Parameters
     ----------
-    missing_values : number, string, np.nan (default) or None
+    missing_values : int, float, str, np.nan or None, default=np.nan
         The placeholder for the missing values. All occurrences of
         `missing_values` will be imputed. For pandas' dataframes with
         nullable integer dtypes with missing values, `missing_values`
@@ -141,6 +143,7 @@ class SimpleImputer(_BaseImputer):
           each column. Can only be used with numeric data.
         - If "most_frequent", then replace missing using the most frequent
           value along each column. Can be used with strings or numeric data.
+          If there is more than one such value, only the smallest is returned.
         - If "constant", then replace missing values with fill_value. Can be
           used with strings or numeric data.
 
@@ -181,11 +184,11 @@ class SimpleImputer(_BaseImputer):
         During :meth:`transform`, features corresponding to `np.nan`
         statistics will be discarded.
 
-    indicator_ : :class:`sklearn.impute.MissingIndicator`
+    indicator_ : :class:`~sklearn.impute.MissingIndicator`
         Indicator used to add binary indicators for missing values.
         ``None`` if add_indicator is False.
 
-    See also
+    See Also
     --------
     IterativeImputer : Multivariate imputation of missing values.
 
@@ -228,7 +231,15 @@ class SimpleImputer(_BaseImputer):
                                                         self.strategy))
 
         if self.strategy in ("most_frequent", "constant"):
-            dtype = None
+            # If input is a list of strings, dtype = object.
+            # Otherwise ValueError is raised in SimpleImputer
+            # with strategy='most_frequent' or 'constant'
+            # because the list is converted to Unicode numpy array
+            if isinstance(X, list) and \
+               any(isinstance(elem, str) for row in X for elem in row):
+                dtype = object
+            else:
+                dtype = None
         else:
             dtype = FLOAT_DTYPES
 
@@ -275,7 +286,6 @@ class SimpleImputer(_BaseImputer):
         self : SimpleImputer
         """
         X = self._validate_input(X, in_fit=True)
-        super()._fit_indicator(X)
 
         # default fill_value is 0 for numerical input and "missing_value"
         # otherwise
@@ -295,7 +305,7 @@ class SimpleImputer(_BaseImputer):
                              "numerical value when imputing numerical "
                              "data".format(fill_value))
 
-        if sparse.issparse(X):
+        if sp.issparse(X):
             # missing_values = 0 not allowed with sparse data as it would
             # force densification
             if self.missing_values == 0:
@@ -307,16 +317,19 @@ class SimpleImputer(_BaseImputer):
                                                     self.strategy,
                                                     self.missing_values,
                                                     fill_value)
+
         else:
             self.statistics_ = self._dense_fit(X,
                                                self.strategy,
                                                self.missing_values,
                                                fill_value)
+
         return self
 
     def _sparse_fit(self, X, strategy, missing_values, fill_value):
         """Fit the transformer on sparse data."""
-        mask_data = _get_mask(X.data, missing_values)
+        missing_mask = _get_mask(X, missing_values)
+        mask_data = missing_mask.data
         n_implicit_zeros = X.shape[0] - np.diff(X.indptr)
 
         statistics = np.empty(X.shape[1])
@@ -349,12 +362,16 @@ class SimpleImputer(_BaseImputer):
                     statistics[i] = _most_frequent(column,
                                                    0,
                                                    n_zeros)
+        super()._fit_indicator(missing_mask)
+
         return statistics
 
     def _dense_fit(self, X, strategy, missing_values, fill_value):
         """Fit the transformer on dense data."""
-        mask = _get_mask(X, missing_values)
-        masked_X = ma.masked_array(X, mask=mask)
+        missing_mask = _get_mask(X, missing_values)
+        masked_X = ma.masked_array(X, mask=missing_mask)
+
+        super()._fit_indicator(missing_mask)
 
         # Mean
         if strategy == "mean":
@@ -382,7 +399,7 @@ class SimpleImputer(_BaseImputer):
 
             # To be able access the elements by columns
             X = X.transpose()
-            mask = mask.transpose()
+            mask = missing_mask.transpose()
 
             if X.dtype.kind == "O":
                 most_frequent = np.empty(X.shape[0], dtype=object)
@@ -390,7 +407,7 @@ class SimpleImputer(_BaseImputer):
                 most_frequent = np.empty(X.shape[0])
 
             for i, (row, row_mask) in enumerate(zip(X[:], mask[:])):
-                row_mask = np.logical_not(row_mask).astype(np.bool)
+                row_mask = np.logical_not(row_mask).astype(bool)
                 row = row[row_mask]
                 most_frequent[i] = _most_frequent(row, np.nan, 0)
 
@@ -413,17 +430,19 @@ class SimpleImputer(_BaseImputer):
         check_is_fitted(self)
 
         X = self._validate_input(X, in_fit=False)
-        X_indicator = super()._transform_indicator(X)
-
         statistics = self.statistics_
 
         if X.shape[1] != statistics.shape[0]:
             raise ValueError("X has %d features per sample, expected %d"
                              % (X.shape[1], self.statistics_.shape[0]))
 
+        # compute mask before eliminating invalid features
+        missing_mask = _get_mask(X, self.missing_values)
+
         # Delete the invalid columns if strategy is not constant
         if self.strategy == "constant":
             valid_statistics = statistics
+            valid_statistics_indexes = None
         else:
             # same as np.isnan but also works for object dtypes
             invalid_mask = _get_mask(statistics, np.nan)
@@ -439,29 +458,100 @@ class SimpleImputer(_BaseImputer):
                 X = X[:, valid_statistics_indexes]
 
         # Do actual imputation
-        if sparse.issparse(X):
+        if sp.issparse(X):
             if self.missing_values == 0:
                 raise ValueError("Imputation not possible when missing_values "
                                  "== 0 and input is sparse. Provide a dense "
                                  "array instead.")
             else:
-                mask = _get_mask(X.data, self.missing_values)
+                # if no invalid statistics are found, use the mask computed
+                # before, else recompute mask
+                if valid_statistics_indexes is None:
+                    mask = missing_mask.data
+                else:
+                    mask = _get_mask(X.data, self.missing_values)
                 indexes = np.repeat(
-                    np.arange(len(X.indptr) - 1, dtype=np.int),
+                    np.arange(len(X.indptr) - 1, dtype=int),
                     np.diff(X.indptr))[mask]
 
                 X.data[mask] = valid_statistics[indexes].astype(X.dtype,
                                                                 copy=False)
         else:
-            mask = _get_mask(X, self.missing_values)
-            n_missing = np.sum(mask, axis=0)
+            # use mask computed before eliminating invalid mask
+            if valid_statistics_indexes is None:
+                mask_valid_features = missing_mask
+            else:
+                mask_valid_features = missing_mask[:, valid_statistics_indexes]
+            n_missing = np.sum(mask_valid_features, axis=0)
             values = np.repeat(valid_statistics, n_missing)
-            coordinates = np.where(mask.transpose())[::-1]
+            coordinates = np.where(mask_valid_features.transpose())[::-1]
 
             X[coordinates] = values
 
+        X_indicator = super()._transform_indicator(missing_mask)
+
         return super()._concatenate_indicator(X, X_indicator)
 
+    def inverse_transform(self, X):
+        """Convert the data back to the original representation.
+
+        Inverts the `transform` operation performed on an array.
+        This operation can only be performed after :class:`SimpleImputer` is
+        instantiated with `add_indicator=True`.
+
+        Note that ``inverse_transform`` can only invert the transform in
+        features that have binary indicators for missing values. If a feature
+        has no missing values at ``fit`` time, the feature won't have a binary
+        indicator, and the imputation done at ``transform`` time won't be
+        inverted.
+
+        .. versionadded:: 0.24
+
+        Parameters
+        ----------
+        X : array-like of shape \
+                (n_samples, n_features + n_features_missing_indicator)
+            The imputed data to be reverted to original data. It has to be
+            an augmented array of imputed data and the missing indicator mask.
+
+        Returns
+        -------
+        X_original : ndarray of shape (n_samples, n_features)
+            The original X with missing values as it was prior
+            to imputation.
+        """
+        check_is_fitted(self)
+
+        if not self.add_indicator:
+            raise ValueError("'inverse_transform' works only when "
+                             "'SimpleImputer' is instantiated with "
+                             "'add_indicator=True'. "
+                             f"Got 'add_indicator={self.add_indicator}' "
+                             "instead.")
+
+        n_features_missing = len(self.indicator_.features_)
+        non_empty_feature_count = X.shape[1] - n_features_missing
+        array_imputed = X[:, :non_empty_feature_count].copy()
+        missing_mask = X[:, non_empty_feature_count:].astype(bool)
+
+        n_features_original = len(self.statistics_)
+        shape_original = (X.shape[0], n_features_original)
+        X_original = np.zeros(shape_original)
+        X_original[:, self.indicator_.features_] = missing_mask
+        full_mask = X_original.astype(bool)
+
+        imputed_idx, original_idx = 0, 0
+        while imputed_idx < len(array_imputed.T):
+            if not np.all(X_original[:, original_idx]):
+                X_original[:, original_idx] = array_imputed.T[imputed_idx]
+                imputed_idx += 1
+                original_idx += 1
+            else:
+                original_idx += 1
+
+        X_original[full_mask] = self.missing_values
+        return X_original
+
 
 class MissingIndicator(TransformerMixin, BaseEstimator):
     """Binary indicators for missing values.
@@ -476,32 +566,32 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
 
     Parameters
     ----------
-    missing_values : number, string, np.nan (default) or None
+    missing_values : int, float, string, np.nan or None, default=np.nan
         The placeholder for the missing values. All occurrences of
         `missing_values` will be imputed. For pandas' dataframes with
         nullable integer dtypes with missing values, `missing_values`
         should be set to `np.nan`, since `pd.NA` will be converted to `np.nan`.
 
-    features : str, default=None
+    features : {'missing-only', 'all'}, default='missing-only'
         Whether the imputer mask should represent all or a subset of
         features.
 
-        - If "missing-only" (default), the imputer mask will only represent
+        - If 'missing-only' (default), the imputer mask will only represent
           features containing missing values during fit time.
-        - If "all", the imputer mask will represent all features.
+        - If 'all', the imputer mask will represent all features.
 
-    sparse : boolean or "auto", default=None
+    sparse : bool or 'auto', default='auto'
         Whether the imputer mask format should be sparse or dense.
 
-        - If "auto" (default), the imputer mask will be of same type as
+        - If 'auto' (default), the imputer mask will be of same type as
           input.
         - If True, the imputer mask will be a sparse matrix.
         - If False, the imputer mask will be a numpy array.
 
-    error_on_new : boolean, default=None
-        If True (default), transform will raise an error when there are
-        features with missing values in transform that have no missing values
-        in fit. This is applicable only when ``features="missing-only"``.
+    error_on_new : bool, default=True
+        If True, transform will raise an error when there are features with
+        missing values in transform that have no missing values in fit. This is
+        applicable only when `features='missing-only'`.
 
     Attributes
     ----------
@@ -558,16 +648,12 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
             The features containing missing values.
 
         """
-        if sparse.issparse(X):
-            mask = _get_mask(X.data, self.missing_values)
+        if not self._precomputed:
+            imputer_mask = _get_mask(X, self.missing_values)
+        else:
+            imputer_mask = X
 
-            # The imputer mask will be constructed with the same sparse format
-            # as X.
-            sparse_constructor = (sparse.csr_matrix if X.format == 'csr'
-                                  else sparse.csc_matrix)
-            imputer_mask = sparse_constructor(
-                (mask, X.indices.copy(), X.indptr.copy()),
-                shape=X.shape, dtype=bool)
+        if sp.issparse(X):
             imputer_mask.eliminate_zeros()
 
             if self.features == 'missing-only':
@@ -578,13 +664,16 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
             elif imputer_mask.format == 'csr':
                 imputer_mask = imputer_mask.tocsc()
         else:
-            imputer_mask = _get_mask(X, self.missing_values)
+            if not self._precomputed:
+                imputer_mask = _get_mask(X, self.missing_values)
+            else:
+                imputer_mask = X
 
             if self.features == 'missing-only':
                 n_missing = imputer_mask.sum(axis=0)
 
             if self.sparse is True:
-                imputer_mask = sparse.csc_matrix(imputer_mask)
+                imputer_mask = sp.csc_matrix(imputer_mask)
 
         if self.features == 'all':
             features_indices = np.arange(X.shape[1])
@@ -610,7 +699,7 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
                              "with integer dtype or an array of string values "
                              "with an object dtype.".format(X.dtype))
 
-        if sparse.issparse(X) and self.missing_values == 0:
+        if sp.issparse(X) and self.missing_values == 0:
             # missing_values = 0 not allowed with sparse data as it would
             # force densification
             raise ValueError("Sparse input with missing_values=0 is "
@@ -619,7 +708,7 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
 
         return X
 
-    def _fit(self, X, y=None):
+    def _fit(self, X, y=None, precomputed=False):
         """Fit the transformer on X.
 
         Parameters
@@ -627,6 +716,11 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
         X : {array-like, sparse matrix}, shape (n_samples, n_features)
             Input data, where ``n_samples`` is the number of samples and
             ``n_features`` is the number of features.
+            If `precomputed` is True, then `X` is a mask of the
+            input data.
+
+        precomputed : bool
+            Whether the input data is a mask.
 
         Returns
         -------
@@ -635,7 +729,19 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
             The imputer mask of the original data.
 
         """
-        X = self._validate_input(X, in_fit=True)
+        if precomputed:
+            if not (hasattr(X, 'dtype') and X.dtype.kind == 'b'):
+                raise ValueError("precomputed is True but the input data is "
+                                 "not a mask")
+            self._precomputed = True
+        else:
+            self._precomputed = False
+
+        # Need not validate X again as it would have already been validated
+        # in the Imputer calling MissingIndicator
+        if not self._precomputed:
+            X = self._validate_input(X, in_fit=True)
+
         self._n_features = X.shape[1]
 
         if self.features not in ('missing-only', 'all'):
@@ -687,11 +793,15 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
 
         """
         check_is_fitted(self)
-        X = self._validate_input(X, in_fit=False)
 
-        if X.shape[1] != self._n_features:
-            raise ValueError("X has a different number of features "
-                             "than during fitting.")
+        # Need not validate X again as it would have already been validated
+        # in the Imputer calling MissingIndicator
+        if not self._precomputed:
+            X = self._validate_input(X, in_fit=False)
+        else:
+            if not (hasattr(X, 'dtype') and X.dtype.kind == 'b'):
+                raise ValueError("precomputed is True but the input data is "
+                                 "not a mask")
 
         imputer_mask, features = self._get_missing_features_info(X)
 
@@ -731,5 +841,8 @@ class MissingIndicator(TransformerMixin, BaseEstimator):
         return imputer_mask
 
     def _more_tags(self):
-        return {'allow_nan': True,
-                'X_types': ['2darray', 'string']}
+        return {
+            "allow_nan": True,
+            "X_types": ["2darray", "string"],
+            "preserves_dtype": [],
+        }
