@@ -4,8 +4,16 @@ import numpy as np
 from numpy import linalg
 
 from scipy.sparse import dok_matrix, csr_matrix, issparse
-from scipy.spatial.distance import cosine, cityblock, minkowski, wminkowski
+from scipy.spatial.distance import cosine, cityblock, minkowski
 from scipy.spatial.distance import cdist, pdist, squareform
+try:
+    from scipy.spatial.distance import wminkowski
+except ImportError:
+    # In scipy 1.6.0, wminkowski is deprecated and minkowski
+    # should be used instead.
+    from scipy.spatial.distance import minkowski as wminkowski
+
+from sklearn.utils.fixes import sp_version, parse_version
 
 import pytest
 
@@ -233,6 +241,7 @@ def test_pairwise_precomputed_non_negative():
         pairwise_distances(np.full((5, 5), -1), metric='precomputed')
 
 
+_minkowski_kwds = {'w': np.arange(1, 5).astype('double', copy=False), 'p': 1}
 _wminkowski_kwds = {'w': np.arange(1, 5).astype('double', copy=False), 'p': 1}
 
 
@@ -245,8 +254,38 @@ def callable_rbf_kernel(x, y, **kwds):
 @pytest.mark.parametrize(
         'func, metric, kwds',
         [(pairwise_distances, 'euclidean', {}),
-         (pairwise_distances, wminkowski, _wminkowski_kwds),
-         (pairwise_distances, 'wminkowski', _wminkowski_kwds),
+         pytest.param(
+             pairwise_distances, minkowski, _minkowski_kwds,
+             marks=pytest.mark.skipif(
+                 sp_version < parse_version("1.0"),
+                 reason="minkowski does not accept the w "
+                        "parameter prior to scipy 1.0."
+             )
+         ),
+         pytest.param(
+             pairwise_distances, 'minkowski', _minkowski_kwds,
+             marks=pytest.mark.skipif(
+                 sp_version < parse_version("1.0"),
+                 reason="minkowski does not accept the w "
+                        "parameter prior to scipy 1.0."
+             )
+         ),
+         pytest.param(
+             pairwise_distances, wminkowski, _wminkowski_kwds,
+             marks=pytest.mark.skipif(
+                 sp_version >= parse_version("1.6.0"),
+                 reason="wminkowski is now minkowski "
+                        "and it has been already tested."
+             )
+         ),
+         pytest.param(
+             pairwise_distances, 'wminkowski', _wminkowski_kwds,
+             marks=pytest.mark.skipif(
+                 sp_version >= parse_version("1.6.0"),
+                 reason="wminkowski is now minkowski "
+                        "and it has been already tested."
+             )
+         ),
          (pairwise_kernels, 'polynomial', {'degree': 1}),
          (pairwise_kernels, callable_rbf_kernel, {'gamma': .1})])
 @pytest.mark.parametrize('array_constr', [np.array, csr_matrix])
@@ -979,7 +1018,7 @@ def test_chi_square_kernel():
     K_add = additive_chi2_kernel(X, Y)
     gamma = 0.1
     K = chi2_kernel(X, Y, gamma=gamma)
-    assert K.dtype == np.float
+    assert K.dtype == float
     for i, x in enumerate(X):
         for j, y in enumerate(Y):
             chi2 = -np.sum((x - y) ** 2 / (x + y))
@@ -1004,7 +1043,7 @@ def test_chi_square_kernel():
     X = rng.random_sample((10, 4)).astype(np.int32)
     K = chi2_kernel(X, X)
     assert np.isfinite(K).all()
-    assert K.dtype == np.float
+    assert K.dtype == float
 
     # check that kernel of similar things is greater than dissimilar ones
     X = [[.3, .7], [1., 0]]
@@ -1240,16 +1279,16 @@ def test_check_preserve_type():
     assert XB_checked.dtype == np.float32
 
     # mismatched A
-    XA_checked, XB_checked = check_pairwise_arrays(XA.astype(np.float),
+    XA_checked, XB_checked = check_pairwise_arrays(XA.astype(float),
                                                    XB)
-    assert XA_checked.dtype == np.float
-    assert XB_checked.dtype == np.float
+    assert XA_checked.dtype == float
+    assert XB_checked.dtype == float
 
     # mismatched B
     XA_checked, XB_checked = check_pairwise_arrays(XA,
-                                                   XB.astype(np.float))
-    assert XA_checked.dtype == np.float
-    assert XB_checked.dtype == np.float
+                                                   XB.astype(float))
+    assert XA_checked.dtype == float
+    assert XB_checked.dtype == float
 
 
 @pytest.mark.parametrize("n_jobs", [1, 2])
@@ -1281,7 +1320,7 @@ def test_pairwise_distances_data_derived_params(n_jobs, metric, dist_function,
                 params = {'VI': np.linalg.inv(np.cov(np.vstack([X, Y]).T)).T}
 
         expected_dist_explicit_params = cdist(X, Y, metric=metric, **params)
-        # TODO: Remove warn_checker in 0.25
+        # TODO: Remove warn_checker in 1.0
         if y_is_x:
             warn_checker = pytest.warns(None)
         else:
