@@ -43,25 +43,23 @@ from .. import get_config
 parallel_backend = _joblib.parallel_backend
 register_parallel_backend = _joblib.register_parallel_backend
 
-
 __all__ = ["murmurhash3_32", "as_float_array",
            "assert_all_finite", "check_array",
            "check_random_state",
            "compute_class_weight", "compute_sample_weight",
-           "column_or_1d", "safe_indexing",
+           "column_or_1d",
            "check_consistent_length", "check_X_y", "check_scalar", 'indexable',
            "check_symmetric", "indices_to_mask", "deprecated",
            "parallel_backend", "register_parallel_backend",
            "resample", "shuffle", "check_matplotlib_support", "all_estimators",
-           "DataConversionWarning", "estimator_html_repr"
-           ]
+           "DataConversionWarning", "estimator_html_repr"]
 
 IS_PYPY = platform.python_implementation() == 'PyPy'
 _IS_32BIT = 8 * struct.calcsize("P") == 32
 
 
 class Bunch(dict):
-    """Container object exposing keys as attributes
+    """Container object exposing keys as attributes.
 
     Bunch objects are sometimes used as an output for functions and methods.
     They extend dictionaries by enabling values to be accessed by key,
@@ -117,7 +115,7 @@ def safe_mask(X, mask):
     X : {array-like, sparse matrix}
         Data on which to apply mask.
 
-    mask : array
+    mask : ndarray
         Mask to be used on X.
 
     Returns
@@ -154,7 +152,7 @@ def axis0_safe_slice(X, mask, len_mask):
     X : {array-like, sparse matrix}
         Data on which to apply mask.
 
-    mask : array
+    mask : ndarray
         Mask to be used on X.
 
     len_mask : int
@@ -270,55 +268,6 @@ def _determine_key_type(key, accept_slice=True):
     raise ValueError(err_msg)
 
 
-# TODO: remove in 0.24
-@deprecated("safe_indexing is deprecated in version "
-            "0.22 and will be removed in version 0.24.")
-def safe_indexing(X, indices, *, axis=0):
-    """Return rows, items or columns of X using indices.
-
-    .. deprecated:: 0.22
-        This function was deprecated in version 0.22 and will be removed in
-        version 0.24.
-
-    Parameters
-    ----------
-    X : array-like, sparse-matrix, list, pandas.DataFrame, pandas.Series
-        Data from which to sample rows, items or columns. `list` are only
-        supported when `axis=0`.
-
-    indices : bool, int, str, slice, array-like
-
-        - If `axis=0`, boolean and integer array-like, integer slice,
-          and scalar integer are supported.
-        - If `axis=1`:
-
-            - to select a single column, `indices` can be of `int` type for
-              all `X` types and `str` only for dataframe. The selected subset
-              will be 1D, unless `X` is a sparse matrix in which case it will
-              be 2D.
-            - to select multiples columns, `indices` can be one of the
-              following: `list`, `array`, `slice`. The type used in
-              these containers can be one of the following: `int`, 'bool' and
-              `str`. However, `str` is only supported when `X` is a dataframe.
-              The selected subset will be 2D.
-
-    axis : int, default=0
-        The axis along which `X` will be subsampled. `axis=0` will select
-        rows while `axis=1` will select columns.
-
-    Returns
-    -------
-    subset
-        Subset of X on axis 0 or 1.
-
-    Notes
-    -----
-    CSR, CSC, and LIL sparse matrices are supported. COO sparse matrices are
-    not supported.
-    """
-    return _safe_indexing(X, indices, axis=axis)
-
-
 def _safe_indexing(X, indices, *, axis=0):
     """Return rows, items or columns of X using indices.
 
@@ -462,43 +411,48 @@ def _get_column_indices(X, key):
                          "strings, or boolean mask is allowed")
 
 
-def resample(*arrays, **options):
-    """Resample arrays or sparse matrices in a consistent way
+def resample(*arrays,
+             replace=True,
+             n_samples=None,
+             random_state=None,
+             stratify=None):
+    """Resample arrays or sparse matrices in a consistent way.
 
     The default strategy implements one step of the bootstrapping
     procedure.
 
     Parameters
     ----------
-    *arrays : sequence of indexable data-structures
+    *arrays : sequence of array-like of shape (n_samples,) or \
+            (n_samples, n_outputs)
         Indexable data-structures can be arrays, lists, dataframes or scipy
         sparse matrices with consistent first dimension.
 
-    Other Parameters
-    ----------------
-    replace : boolean, True by default
+    replace : bool, default=True
         Implements resampling with replacement. If False, this will implement
         (sliced) random permutations.
 
-    n_samples : int, None by default
+    n_samples : int, default=None
         Number of samples to generate. If left to None this is
         automatically set to the first dimension of the arrays.
         If replace is False it should not be larger than the length of
         arrays.
 
-    random_state : int, RandomState instance or None, optional (default=None)
+    random_state : int, RandomState instance or None, default=None
         Determines random number generation for shuffling
         the data.
         Pass an int for reproducible results across multiple function calls.
         See :term:`Glossary <random_state>`.
 
-    stratify : array-like or None (default=None)
+    stratify : array-like of shape (n_samples,) or (n_samples, n_outputs), \
+            default=None
         If not None, data is split in a stratified fashion, using this as
         the class labels.
 
     Returns
     -------
-    resampled_arrays : sequence of indexable data-structures
+    resampled_arrays : sequence of array-like of shape (n_samples,) or \
+            (n_samples, n_outputs)
         Sequence of resampled copies of the collections. The original arrays
         are not impacted.
 
@@ -541,18 +495,12 @@ def resample(*arrays, **options):
       ...          random_state=0)
       [1, 1, 1, 0, 1]
 
-
-    See also
+    See Also
     --------
-    :func:`sklearn.utils.shuffle`
+    shuffle
     """
-
-    random_state = check_random_state(options.pop('random_state', None))
-    replace = options.pop('replace', True)
-    max_n_samples = options.pop('n_samples', None)
-    stratify = options.pop('stratify', None)
-    if options:
-        raise ValueError("Unexpected kw arguments: %r" % options.keys())
+    max_n_samples = n_samples
+    random_state = check_random_state(random_state)
 
     if len(arrays) == 0:
         return None
@@ -605,7 +553,6 @@ def resample(*arrays, **options):
 
         indices = random_state.permutation(indices)
 
-
     # convert sparse matrices to CSR for row-based indexing
     arrays = [a.tocsr() if issparse(a) else a for a in arrays]
     resampled_arrays = [_safe_indexing(a, indices) for a in arrays]
@@ -616,8 +563,8 @@ def resample(*arrays, **options):
         return resampled_arrays
 
 
-def shuffle(*arrays, **options):
-    """Shuffle arrays or sparse matrices in a consistent way
+def shuffle(*arrays, random_state=None, n_samples=None):
+    """Shuffle arrays or sparse matrices in a consistent way.
 
     This is a convenience alias to ``resample(*arrays, replace=False)`` to do
     random permutations of the collections.
@@ -628,17 +575,16 @@ def shuffle(*arrays, **options):
         Indexable data-structures can be arrays, lists, dataframes or scipy
         sparse matrices with consistent first dimension.
 
-    Other Parameters
-    ----------------
-    random_state : int, RandomState instance or None, optional (default=None)
+    random_state : int, RandomState instance or None, default=None
         Determines random number generation for shuffling
         the data.
         Pass an int for reproducible results across multiple function calls.
         See :term:`Glossary <random_state>`.
 
-    n_samples : int, None by default
+    n_samples : int, default=None
         Number of samples to generate. If left to None this is
-        automatically set to the first dimension of the arrays.
+        automatically set to the first dimension of the arrays.  It should
+        not be larger than the length of arrays.
 
     Returns
     -------
@@ -678,12 +624,12 @@ def shuffle(*arrays, **options):
       >>> shuffle(y, n_samples=2, random_state=0)
       array([0, 1])
 
-    See also
+    See Also
     --------
-    :func:`sklearn.utils.resample`
+    resample
     """
-    options['replace'] = False
-    return resample(*arrays, **options)
+    return resample(*arrays, replace=False, n_samples=n_samples,
+                    random_state=random_state)
 
 
 @_deprecate_positional_args
@@ -692,9 +638,9 @@ def safe_sqr(X, *, copy=True):
 
     Parameters
     ----------
-    X : array like, matrix, sparse matrix
+    X : {array-like, ndarray, sparse matrix}
 
-    copy : boolean, optional, default True
+    copy : bool, default=True
         Whether to create a copy of X and operate on it or to perform
         inplace computation (default behaviour).
 
@@ -737,7 +683,7 @@ def gen_batches(n, batch_size, *, min_batch_size=0):
     ----------
     n : int
     batch_size : int
-        Number of element in each batch
+        Number of element in each batch.
     min_batch_size : int, default=0
         Minimum batch size to produce.
 
@@ -785,7 +731,7 @@ def gen_even_slices(n, n_packs, *, n_samples=None):
     n : int
     n_packs : int
         Number of slices to generate.
-    n_samples : int or None (default = None)
+    n_samples : int, default=None
         Number of samples. Pass n_samples when the slices are to be used for
         sparse matrix indexing; slicing off-the-end raises an exception, while
         it works for NumPy arrays.
@@ -865,10 +811,7 @@ def _to_object_array(sequence):
     array([array([0]), array([1])], dtype=object)
     >>> _to_object_array([np.array([0]), np.array([1, 2])])
     array([array([0]), array([1, 2])], dtype=object)
-    >>> np.array([np.array([0]), np.array([1])])
-    array([[0],
-       [1]])
-    >>> np.array([np.array([0]), np.array([1, 2])])
+    >>> _to_object_array([np.array([0]), np.array([1, 2])])
     array([array([0]), array([1, 2])], dtype=object)
     """
     out = np.empty(len(sequence), dtype=object)
@@ -885,7 +828,7 @@ def indices_to_mask(indices, mask_length):
         List of integers treated as indices.
     mask_length : int
         Length of boolean mask to be generated.
-        This parameter must be greater than max(indices)
+        This parameter must be greater than max(indices).
 
     Returns
     -------
@@ -902,25 +845,25 @@ def indices_to_mask(indices, mask_length):
     if mask_length <= np.max(indices):
         raise ValueError("mask_length must be greater than max(indices)")
 
-    mask = np.zeros(mask_length, dtype=np.bool)
+    mask = np.zeros(mask_length, dtype=bool)
     mask[indices] = True
 
     return mask
 
 
 def _message_with_time(source, message, time):
-    """Create one line message for logging purposes
+    """Create one line message for logging purposes.
 
     Parameters
     ----------
     source : str
-        String indicating the source or the reference of the message
+        String indicating the source or the reference of the message.
 
     message : str
-        Short message
+        Short message.
 
     time : int
-        Time in seconds
+        Time in seconds.
     """
     start_message = "[%s] " % source
 
@@ -937,20 +880,20 @@ def _message_with_time(source, message, time):
 
 @contextmanager
 def _print_elapsed_time(source, message=None):
-    """Log elapsed time to stdout when the context is exited
+    """Log elapsed time to stdout when the context is exited.
 
     Parameters
     ----------
     source : str
-        String indicating the source or the reference of the message
+        String indicating the source or the reference of the message.
 
-    message : str or None
-        Short message. If None, nothing will be printed
+    message : str, default=None
+        Short message. If None, nothing will be printed.
 
     Returns
     -------
     context_manager
-        Prints elapsed time upon exit if verbose
+        Prints elapsed time upon exit if verbose.
     """
     if message is None:
         yield
@@ -964,16 +907,16 @@ def _print_elapsed_time(source, message=None):
 
 @_deprecate_positional_args
 def get_chunk_n_rows(row_bytes, *, max_n_rows=None, working_memory=None):
-    """Calculates how many rows can be processed within working_memory
+    """Calculates how many rows can be processed within working_memory.
 
     Parameters
     ----------
     row_bytes : int
         The expected number of bytes of memory that will be consumed
         during the processing of each row.
-    max_n_rows : int, optional
+    max_n_rows : int, default=None
         The maximum return value.
-    working_memory : int or float, optional
+    working_memory : int or float, default=None
         The number of rows to fit inside this number of MiB will be returned.
         When None (default), the value of
         ``sklearn.get_config()['working_memory']`` is used.
@@ -1002,10 +945,10 @@ def get_chunk_n_rows(row_bytes, *, max_n_rows=None, working_memory=None):
 
 
 def is_scalar_nan(x):
-    """Tests if x is NaN
+    """Tests if x is NaN.
 
     This function is meant to overcome the issue that np.isnan does not allow
-    non-numerical types as input, and that np.nan is not np.float('nan').
+    non-numerical types as input, and that np.nan is not float('nan').
 
     Parameters
     ----------
@@ -1099,7 +1042,7 @@ def _approximate_mode(class_counts, n_draws, rng):
             need_to_add -= add_now
             if need_to_add == 0:
                 break
-    return floored.astype(np.int)
+    return floored.astype(int)
 
 
 def check_matplotlib_support(caller_name):
@@ -1123,7 +1066,7 @@ def check_matplotlib_support(caller_name):
 
 
 def check_pandas_support(caller_name):
-    """Raise ImportError with detailed error message if pandsa is not
+    """Raise ImportError with detailed error message if pandas is not
     installed.
 
     Plot utilities like :func:`fetch_openml` should lazily import
@@ -1149,11 +1092,11 @@ def all_estimators(type_filter=None):
     This function crawls the module and gets all classes that inherit
     from BaseEstimator. Classes that are defined in test-modules are not
     included.
-    By default meta_estimators such as GridSearchCV are also not included.
 
     Parameters
     ----------
-    type_filter : string, list of string,  or None, default=None
+    type_filter : {"classifier", "regressor", "cluster", "transformer"} \
+            or list of such str, default=None
         Which kind of estimators should be returned. If None, no filter is
         applied and all estimators are returned.  Possible values are
         'classifier', 'regressor', 'cluster' and 'transformer' to get
