@@ -18,7 +18,6 @@ import warnings
 from scipy.optimize.linesearch import line_search_wolfe2, line_search_wolfe1
 
 from ..exceptions import ConvergenceWarning
-from . import deprecated
 
 
 class _LineSearchError(RuntimeError):
@@ -35,7 +34,7 @@ def _line_search_wolfe12(f, fprime, xk, pk, gfk, old_fval, old_old_fval,
     Raises
     ------
     _LineSearchError
-        If no suitable step size is found
+        If no suitable step size is found.
 
     """
     ret = line_search_wolfe1(f, fprime, xk, pk, gfk,
@@ -62,10 +61,10 @@ def _cg(fhess_p, fgrad, maxiter, tol):
     ----------
     fhess_p : callable
         Function that takes the gradient as a parameter and returns the
-        matrix product of the Hessian and gradient
+        matrix product of the Hessian and gradient.
 
-    fgrad : ndarray, shape (n_features,) or (n_features + 1,)
-        Gradient vector
+    fgrad : ndarray of shape (n_features,) or (n_features + 1,)
+        Gradient vector.
 
     maxiter : int
         Number of CG iterations.
@@ -75,8 +74,8 @@ def _cg(fhess_p, fgrad, maxiter, tol):
 
     Returns
     -------
-    xsupi : ndarray, shape (n_features,) or (n_features + 1,)
-        Estimated solution
+    xsupi : ndarray of shape (n_features,) or (n_features + 1,)
+        Estimated solution.
     """
     xsupi = np.zeros(len(fgrad), dtype=fgrad.dtype)
     ri = fgrad
@@ -112,14 +111,6 @@ def _cg(fhess_p, fgrad, maxiter, tol):
     return xsupi
 
 
-@deprecated("newton_cg is deprecated in version "
-            "0.22 and will be removed in version 0.24.")
-def newton_cg(grad_hess, func, grad, x0, args=(), tol=1e-4,
-              maxiter=100, maxinner=200, line_search=True, warn=True):
-    return _newton_cg(grad_hess, func, grad, x0, args, tol, maxiter,
-                      maxinner, line_search, warn)
-
-
 def _newton_cg(grad_hess, func, grad, x0, args=(), tol=1e-4,
                maxiter=100, maxinner=200, line_search=True, warn=True):
     """
@@ -142,24 +133,24 @@ def _newton_cg(grad_hess, func, grad, x0, args=(), tol=1e-4,
     x0 : array of float
         Initial guess.
 
-    args : tuple, optional
+    args : tuple, default=()
         Arguments passed to func_grad_hess, func and grad.
 
-    tol : float
+    tol : float, default=1e-4
         Stopping criterion. The iteration will stop when
         ``max{|g_i | i = 1, ..., n} <= tol``
         where ``g_i`` is the i-th component of the gradient.
 
-    maxiter : int
+    maxiter : int, default=100
         Number of Newton iterations.
 
-    maxinner : int
+    maxinner : int, default=200
         Number of CG iterations.
 
-    line_search : boolean
+    line_search : bool, default=True
         Whether to use a line search or not.
 
-    warn : boolean
+    warn : bool, default=True
         Whether to warn when didn't converge.
 
     Returns
@@ -219,28 +210,38 @@ def _check_optimize_result(solver, result, max_iter=None,
 
     Parameters
     ----------
-    solver: str
-       solver name. Currently only `lbfgs` is supported.
-    result: OptimizeResult
-       result of the scipy.optimize.minimize function
-    max_iter: {int, None}
-       expected maximum number of iterations
+    solver : str
+       Solver name. Currently only `lbfgs` is supported.
+
+    result : OptimizeResult
+       Result of the scipy.optimize.minimize function.
+
+    max_iter : int, default=None
+       Expected maximum number of iterations.
+
+    extra_warning_msg : str, default=None
+        Extra warning message.
 
     Returns
     -------
-    n_iter: int
-       number of iterations
+    n_iter : int
+       Number of iterations.
     """
     # handle both scipy and scikit-learn solver names
     if solver == "lbfgs":
         if result.status != 0:
+            try:
+                # The message is already decoded in scipy>=1.6.0
+                result_message = result.message.decode("latin1")
+            except AttributeError:
+                result_message = result.message
             warning_msg = (
                 "{} failed to converge (status={}):\n{}.\n\n"
                 "Increase the number of iterations (max_iter) "
                 "or scale the data as shown in:\n"
                 "    https://scikit-learn.org/stable/modules/"
                 "preprocessing.html"
-            ).format(solver, result.status, result.message.decode("latin1"))
+            ).format(solver, result.status, result_message)
             if extra_warning_msg is not None:
                 warning_msg += "\n" + extra_warning_msg
             warnings.warn(warning_msg, ConvergenceWarning, stacklevel=2)
